---
title: genomic_region
---

## Genomic Region processing

:::gentropy.common.genomic_region.KnownGenomicRegions
:::gentropy.common.genomic_region.GenomicRegion

## LiftOver

:::gentropy.common.genomic_region.LiftOverSpark
:::gentropy.common.genomic_region.liftover_loci
